function [ Area, I, J ] = Sec_Prop_Circle( Diameter )
%
%  Sec_Prop_Circle
%
%        This routine computes the section properties of a circle
%
%  Input
%    Diameter     The diameter of the circle
%
%  Output
%    Area    The area of the circle
%    I       The second moment of inertia
%    J       The polar second moment of inertia
%

Area = pi * Diameter ^ 2 / 4;
I = pi * Diameter ^ 4 / 64;
J = 2 * I;

end

